@@ -27,12 +27,7 @@ from jaraco import path
 from setuptools import sandbox
 from setuptools.sandbox import run_setup
 import setuptools.command.easy_install as ei
-from setuptools.command.easy_install import (
-    EasyInstallDeprecationWarning,
-    ScriptWriter,
-    PthDistributions,
-    WindowsScriptWriter,
-)
+from setuptools.command.easy_install import PthDistributions
 from setuptools.dist import Distribution
 from pkg_resources import normalize_path, working_set
 from pkg_resources import Distribution as PRDistribution
@@ -295,22 +290,6 @@ class TestEasyInstallTest:
         cmd.easy_install(sdist_script)
         assert (target / 'mypkg_script').exists()
 
-    def test_dist_get_script_args_deprecated(self):
-        with pytest.warns(EasyInstallDeprecationWarning):
-            ScriptWriter.get_script_args(None, None)
-
-    def test_dist_get_script_header_deprecated(self):
-        with pytest.warns(EasyInstallDeprecationWarning):
-            ScriptWriter.get_script_header("")
-
-    def test_dist_get_writer_deprecated(self):
-        with pytest.warns(EasyInstallDeprecationWarning):
-            ScriptWriter.get_writer(None)
-
-    def test_dist_WindowsScriptWriter_get_writer_deprecated(self):
-        with pytest.warns(EasyInstallDeprecationWarning):
-            WindowsScriptWriter.get_writer()
-
 
 @pytest.mark.filterwarnings('ignore:Unbuilt egg')
 class TestPTHFileWriter:
@@ -697,6 +676,7 @@ class TestSetupRequires:
                 foobar_1_dir = os.path.join(temp_dir, 'foo.bar-0.1')
                 os.mkdir(foobar_1_dir)
                 with tarfile.open(foobar_1_archive) as tf:
+                    tf.extraction_filter = (lambda member, path: member)
                     tf.extractall(foobar_1_dir)
                 sys.path.insert(1, foobar_1_dir)
 
