@@ -14,9 +14,7 @@ from jaraco import path
 
 from setuptools import errors
 from setuptools.command.egg_info import (
-    EggInfoDeprecationWarning,
     egg_info,
-    get_pkg_info_revision,
     manifest_maker,
     write_entries,
 )
@@ -1105,9 +1103,6 @@ class TestEggInfo:
             pkg_info_lines = pkginfo_file.read().split('\n')
         assert 'Version: 0.0.0.dev0' in pkg_info_lines
 
-    def test_get_pkg_info_revision_deprecated(self):
-        pytest.warns(EggInfoDeprecationWarning, get_pkg_info_revision)
-
 
 class TestWriteEntries:
 
